==> paycenter-client-3.4.23-20230720.091828-2-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/shenzhenumsunionpay/UnionPayUmsRefundQueryBody.java <==
package cn.com.duiba.paycenter.dto.payment.charge.shenzhenumsunionpay;

/**
 * @author UnionPayUmsRefundQueryRequest
 * @Description
 * @date 2023/7/19 10:45
 */
public class UnionPayUmsRefundQueryBody {
    //消息ID
    String msgId;
    //报文请求时间，格式yyyy-MM-ddHH:mm:ss
    String requestTimestamp;
    //报文系统预留字段
    String srcReserve;
    //商户订单号
    String merOrderId;
    //商户号
    String mid;
    //终端号
    String tid;
    //业务类型
    String instMid;

    private UnionPayUmsRefundQueryBody(Builder builder) {
        setMsgId(builder.msgId);
        setRequestTimestamp(builder.requestTimestamp);
        setSrcReserve(builder.srcReserve);
        setMerOrderId(builder.merOrderId);
        setMid(builder.mid);
        setTid(builder.tid);
        setInstMid(builder.instMid);
    }

    public String getMsgId() {
        return msgId;
    }

    public void setMsgId(String msgId) {
        this.msgId = msgId;
    }

    public String getRequestTimestamp() {
        return requestTimestamp;
    }

    public void setRequestTimestamp(String requestTimestamp) {
        this.requestTimestamp = requestTimestamp;
    }

    public String getSrcReserve() {
        return srcReserve;
    }

    public void setSrcReserve(String srcReserve) {
        this.srcReserve = srcReserve;
    }

    public String getMerOrderId() {
        return merOrderId;
    }

    public void setMerOrderId(String merOrderId) {
        this.merOrderId = merOrderId;
    }

    public String getMid() {
        return mid;
    }

    public void setMid(String mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getInstMid() {
        return instMid;
    }

    public void setInstMid(String instMid) {
        this.instMid = instMid;
    }


    public static final class Builder {
        private String msgId;
        private String requestTimestamp;
        private String srcReserve;
        private String merOrderId;
        private String mid;
        private String tid;
        private String instMid;

        public Builder() {
        }

        public Builder msgId(String val) {
            msgId = val;
            return this;
        }

        public Builder requestTimestamp(String val) {
            requestTimestamp = val;
            return this;
        }

        public Builder srcReserve(String val) {
            srcReserve = val;
            return this;
        }

        public Builder merOrderId(String val) {
            merOrderId = val;
            return this;
        }

        public Builder mid(String val) {
            mid = val;
            return this;
        }

        public Builder tid(String val) {
            tid = val;
            return this;
        }

        public Builder instMid(String val) {
            instMid = val;
            return this;
        }

        public UnionPayUmsRefundQueryBody build() {
            return new UnionPayUmsRefundQueryBody(this);
        }
    }
}

==> paycenter-client-3.5.35-20250915.094345-1-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/shenzhenumsunionpay/UnionPayUmsRefundQueryBody.java <==
package cn.com.duiba.paycenter.dto.payment.charge.shenzhenumsunionpay;

import java.io.Serializable;

/**
 * @author UnionPayUmsRefundQueryRequest
 * @Description
 * @date 2023/7/19 10:45
 */
public class UnionPayUmsRefundQueryBody implements Serializable {
    //消息ID
    String msgId;
    //报文请求时间，格式yyyy-MM-ddHH:mm:ss
    String requestTimestamp;
    //报文系统预留字段
    String srcReserve;
    //商户订单号
    String merOrderId;
    //商户号
    String mid;
    //终端号
    String tid;
    //业务类型
    String instMid;



    public String getMsgId() {
        return msgId;
    }

    public void setMsgId(String msgId) {
        this.msgId = msgId;
    }

    public String getRequestTimestamp() {
        return requestTimestamp;
    }

    public void setRequestTimestamp(String requestTimestamp) {
        this.requestTimestamp = requestTimestamp;
    }

    public String getSrcReserve() {
        return srcReserve;
    }

    public void setSrcReserve(String srcReserve) {
        this.srcReserve = srcReserve;
    }

    public String getMerOrderId() {
        return merOrderId;
    }

    public void setMerOrderId(String merOrderId) {
        this.merOrderId = merOrderId;
    }

    public String getMid() {
        return mid;
    }

    public void setMid(String mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getInstMid() {
        return instMid;
    }

    public void setInstMid(String instMid) {
        this.instMid = instMid;
    }




}
